<h1>API de la poutre d'escalade XBoard</h1>

Cette API permet de lancer des exercices sur la poutre une fois que celle-ci est connectée.


<h1>Exemples d'exercices</h1>
<p>Ci-dessous, quelques exercices sont proposés pour servir de base</p>

<li>Démonstration des fonctionnalités</li>
https://colab.research.google.com/github/CossartSim/XBoard/blob/main/examples/demo.ipynb

<li>Détermination de la force critique</li>
https://colab.research.google.com/github/CossartSim/XBoard/blob/main/examples/force_critique.ipynb